@@ -37,6 +37,15 @@ class CommonLib:
         else:
             return None
 
+    @staticmethod
+    def getRemoteByte(url):
+        http = urllib3.PoolManager()
+        r = http.request('GET', url)
+        if r.status == 200:
+            return bytes(r.data), r.headers.get("filename", "")
+        else:
+            return None
+
     @staticmethod
     def getNowTime():
         tz = pytz.timezone('Asia/Shanghai')
